c       fortran 90 version  1D histogram
      type histogram1
         type(histoc) c
         type(histogram) x
         real, allocatable ::  xw(:)
         real, allocatable ::  dnw(:)
         real, allocatable ::  dndx(:)
         real, allocatable ::  mean(:)
         real, allocatable ::  xforI(:)
         real, allocatable ::  integ(:)
      end type

